@@ -45,6 +45,12 @@ static gboolean gda_mysql_provider_open_connection (GdaServerProvider *provider,
 						    const gchar *password);
 static gboolean gda_mysql_provider_close_connection (GdaServerProvider *provider,
 						     GdaConnection *cnc);
+static gboolean gda_mysql_provider_create_database (GdaServerProvider *provider,
+						    GdaConnection *cnc,
+						    const gchar *name);
+static gboolean gda_mysql_provider_drop_database (GdaServerProvider *provider,
+						  GdaConnection *cnc,
+						  const gchar *name);
 static GList *gda_mysql_provider_execute_command (GdaServerProvider *provider,
 						  GdaConnection *cnc,
 						  GdaCommand *cmd,
@@ -83,6 +89,8 @@ gda_mysql_provider_class_init (GdaMysqlProviderClass *klass)
 	object_class->finalize = gda_mysql_provider_finalize;
 	provider_class->open_connection = gda_mysql_provider_open_connection;
 	provider_class->close_connection = gda_mysql_provider_close_connection;
+	provider_class->create_database = gda_mysql_provider_create_database;
+	provider_class->drop_database = gda_mysql_provider_drop_database;
 	provider_class->execute_command = gda_mysql_provider_execute_command;
 	provider_class->begin_transaction = gda_mysql_provider_begin_transaction;
 	provider_class->commit_transaction = gda_mysql_provider_commit_transaction;
@@ -263,7 +271,7 @@ process_sql_commands (GList *reclist, GdaConnection *cnc, const gchar *sql)
 		while (arr[n]) {
 			gint rc;
 			MYSQL_RES *mysql_res;
-			GdaRecordset *recset;
+			GdaMysqlRecordset *recset;
 
 			rc = mysql_real_query (mysql, arr[n], strlen (arr[n]));
 			if (rc != 0) {
@@ -273,8 +281,11 @@ process_sql_commands (GList *reclist, GdaConnection *cnc, const gchar *sql)
 
 			mysql_res = mysql_store_result (mysql);
 			recset = gda_mysql_recordset_new (cnc, mysql_res);
-			if (GDA_IS_RECORDSET (recset))
+			if (GDA_IS_MYSQL_RECORDSET (recset)) {
+				gda_data_model_set_command_text (recset, arr[n]);
+				gda_data_model_set_command_type (recset, GDA_COMMAND_TYPE_SQL);
 				reclist = g_list_append (reclist, recset);
+			}
 
 			n++;
 		}
@@ -285,6 +296,72 @@ process_sql_commands (GList *reclist, GdaConnection *cnc, const gchar *sql)
 	return reclist;
 }
 
+/* create_database handler for the GdaMysqlProvider class */
+static gboolean
+gda_mysql_provider_create_database (GdaServerProvider *provider,
+				    GdaConnection *cnc,
+				    const gchar *name)
+{
+	gint rc;
+	MYSQL *mysql;
+	gchar *sql;
+	GdaMysqlProvider *myprv = (GdaMysqlProvider *) provider;
+
+	g_return_val_if_fail (GDA_IS_MYSQL_PROVIDER (myprv), FALSE);
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
+	g_return_val_if_fail (name != NULL, FALSE);
+
+	mysql = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_MYSQL_HANDLE);
+	if (!mysql) {
+		gda_connection_add_error_string (cnc, _("Invalid MYSQL handle"));
+		return FALSE;
+	}
+
+	sql = g_strdup_printf ("CREATE DATABASE %s", name);
+	rc = mysql_real_query (mysql, sql, strlen (sql));
+	g_free (sql);
+
+	if (rc != 0) {
+		gda_connection_add_error (cnc, gda_mysql_make_error (mysql));
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+/* drop_database handler for the GdaMysqlProvider class */
+static gboolean
+gda_mysql_provider_drop_database (GdaServerProvider *provider,
+				  GdaConnection *cnc,
+				  const gchar *name)
+{
+	gint rc;
+	MYSQL *mysql;
+	gchar *sql;
+	GdaMysqlProvider *myprv = (GdaMysqlProvider *) provider;
+
+	g_return_val_if_fail (GDA_IS_MYSQL_PROVIDER (myprv), FALSE);
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
+	g_return_val_if_fail (name != NULL, FALSE);
+
+	mysql = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_MYSQL_HANDLE);
+	if (!mysql) {
+		gda_connection_add_error_string (cnc, _("Invalid MYSQL handle"));
+		return FALSE;
+	}
+
+	sql = g_strdup_printf ("DROP DATABASE IF EXISTS %s", name);
+	rc = mysql_real_query (mysql, sql, strlen (sql));
+	g_free (sql);
+
+	if (rc != 0) {
+		gda_connection_add_error (cnc, gda_mysql_make_error (mysql));
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 /* execute_command handler for the GdaMysqlProvider class */
 static GList *
 gda_mysql_provider_execute_command (GdaServerProvider *provider,
@@ -307,6 +384,13 @@ gda_mysql_provider_execute_command (GdaServerProvider *provider,
 	case GDA_COMMAND_TYPE_TABLE :
 		str = g_strdup_printf ("SELECT * FROM %s", gda_command_get_text (cmd));
 		reclist = process_sql_commands (reclist, cnc, str);
+		if (reclist && GDA_IS_DATA_MODEL (reclist->data)) {
+			gda_data_model_set_command_text (GDA_DATA_MODEL (reclist->data),
+							 gda_command_get_text (cmd));
+			gda_data_model_set_command_type (GDA_DATA_MODEL (reclist->data),
+							 GDA_COMMAND_TYPE_TABLE);
+		}
+
 		g_free (str);
 		break;
 	default:
@@ -410,6 +494,7 @@ gda_mysql_provider_supports (GdaServerProvider *provider,
 	g_return_val_if_fail (GDA_IS_MYSQL_PROVIDER (myprv), FALSE);
 
 	switch (feature) {
+	case GDA_CONNECTION_FEATURE_AGGREGATES :
 	case GDA_CONNECTION_FEATURE_SQL :
 	case GDA_CONNECTION_FEATURE_TRANSACTIONS :
 		return TRUE;
@@ -432,7 +517,7 @@ add_string_row (GdaDataModelArray *recset, const gchar *str)
 	list.next = NULL;
 	list.prev = NULL;
 
-	gda_data_model_array_append_row (recset, &list);
+	gda_data_model_append_row (GDA_DATA_MODEL (recset), &list);
 
 	gda_value_free (value);
 }
@@ -596,7 +681,7 @@ static GdaDataModel *
 get_mysql_databases (GdaConnection *cnc, GdaParameterList *params)
 {
 	GList *reclist;
-	GdaRecordset *recset;
+	GdaMysqlRecordset *recset;
 
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
 
@@ -604,7 +689,7 @@ get_mysql_databases (GdaConnection *cnc, GdaParameterList *params)
 	if (!reclist)
 		return NULL;
 
-	recset = GDA_RECORDSET (reclist->data);
+	recset = GDA_MYSQL_RECORDSET (reclist->data);
 	g_list_free (reclist);
 
 	return GDA_DATA_MODEL (recset);
@@ -614,7 +699,7 @@ static GdaDataModel *
 get_mysql_tables (GdaConnection *cnc, GdaParameterList *params)
 {
 	GList *reclist;
-	GdaRecordset *recset;
+	GdaMysqlRecordset *recset;
 
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
 
@@ -622,7 +707,7 @@ get_mysql_tables (GdaConnection *cnc, GdaParameterList *params)
 	if (!reclist)
 		return NULL;
 
-	recset = GDA_RECORDSET (reclist->data);
+	recset = GDA_MYSQL_RECORDSET (reclist->data);
 	g_list_free (reclist);
 
 	return GDA_DATA_MODEL (recset);
@@ -818,7 +903,8 @@ get_table_fields (GdaConnection *cnc, GdaParameterList *params)
 			return NULL;
 		}
 
-		gda_data_model_array_append_row (recset, (const GList *) value_list);
+		gda_data_model_append_row (GDA_DATA_MODEL (recset),
+					   (const GList *) value_list);
 
 		g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 		g_list_free (value_list);
